utils::globalVariables(
  c(
    "ABD_dw", "ABD_up", "ABDsd", "ABDse", 
    "BA", "BAI_dw", "BAI_up", "BAImean", "BAIsd", "BAIse", "BA_diff",
    
    "MaxSamples", "N_ageBands", "N_trees", "Ntree_age", "Ntrees", "Ntrees_label",
    
    "TRW", "TRW_cumsum", "TRW_dw", "TRW_label", "TRW_up", "TRWmean", "TRWsd", "TRWse",
    "ageBands", "age_class", "age_class1010", "age_class1020", "age_class1020_o",
    "age_class_ToBeIncluded", "eTh", "end_year",
    "meanTRW", "mean_stdTRW_year", "nSamples", "name", "norm_out",
    "sampRatio", "start_year", "starts_with", "stdTRW_byAgeClass",
    "tree_code", "value", "y_age_code", "year", "year_range",
    "TRW_cumsum_arg",
    
    # Aggiunte per import_rwl
    "tree", "pith.offset", "first_year", "offset_data"
  )
)